*! Program to estimate the GMM spatial model a la Conley (Mata version)
*! by P. Wilner Jeanty
*! For a version using old syntax and the Stata's matrix commands vecaccum and opaccum, see Conley's website
*! Version 2.0.0: September 2012 - Option km, degree added
*! Version 1.0.1: July 2011      - Option first added
*! Version 1.0.0: December 2010  - Born 

program define spcgmm, eclass  // to finish making it byable
	version 10.1
	if !replay() {
		syntax varlist(min=1 numeric) [if] [in], coord(varlist min=2 max=2) ///
		CUToff(numlist min=2 max=2 >0) [km EXog(varlist) ENdog(varlist)     ///
		Level(real 95) COLlinear NOCONSt First degree]
		
		marksample touse
		local exo ""
		local endo ""
		local ivm=0
		if "`exog'"!="" & "`endog'"!="" {
			if "`:list exog & endog'"!="" {
				di as err "Variables `:list inst & endog' cannot be both exogenous and endogenous"
				error 198
			}
			markout `touse' `exog' `endog' 
			local wex : word count `exog'
			local wend : word count `endog'
			if  `wex' <`wend' {
				di in red "underidentified system"
				exit 198
			}
			local exo `exog'
			local endo `endog'	
			
			local ivm=1
		}
		if "`km'"!="" & "`degree'"!="" { // if none of km and degrees is specified, the default is mile
			di as err "Options km and degree may not be combined"
			exit 198
		}	
		gettoken Y incexog:varlist
		local rmcons=cond("`noconstant'"!="", "noconstant", "")
		local addcons=cond("`noconstant'"!="", "", "_cons")

		local hvar "`incexog' `exo'"
		
		* Check for collinearity
		_rmcoll `hvar' if `touse', `collinear' `rmcons'
		local okvars `r(varlist)'	
		local notokvars : list hvar - okvars
		local exog : list exo - notokvars
		local incexog :list incexog - notokvars
		local hvar `incexog' `addcons' `exog' 
		di "`hvar'"
		local zvar "`endo' `incexog'" 
		local wzv : word count `zvar'
		local inst : word count `hvar'
		local xreg=cond("`noconst'"!="", `wzv', `wzv'+1)
		local wc : word count `coord'
		if `ivm'==1 {		
			if "`first'"!="" {
				foreach var of varlist `endog' {
					di
					di "  {ul:First stage regression}"
					regress `var' `incexog' `exog'
				}
			}
		}
		if `ivm'==0 & "`first'"!="" {
			di as err "Option first not allowed when option endog() is not specified"
			exit 198
		}	
		tempname  binit vinit cut
		mat `cut'=J(1,`wc',0)
		local s=1
		foreach num of numlist `cutoff' {
			mat `cut'[1,`s']=`num'
			local ++s
		}		
		mata: spcgmm_funct("`Y'", "`zvar'", "`incexog'", "`exog'", "`coord'", "`cut'", "`touse'")
		tempname Wght
		mat B=r(b)
		mat V=r(V)
		mat `Wght'=r(w)
		local ovk=`inst'-`xreg'
		local dof=_N - `xreg'
		local J=scalar(J)
		local p_j=chi2tail(`ovk', `J')
		qui count if `touse'
		local N = r(n)
		ereturn clear
		ereturn post B V, obs(`N') depname(`Y') dof(`dof') esample(`touse')
		ereturn scalar DF=`ovk'
		// ereturn scalar cut =`cutoff'
		ereturn local depvar "`Y'"
		ereturn local exogr "`incexog'"
		if `ivm'==1 {
			ereturn local instd "`endog'"		
			ereturn local insts "`incexog' `exog'"
			ereturn local predict "ivregress_p"
			ereturn local estat_cmd "ivregress_estat"			
		}
		else {
			ereturn local predict "regress_p"
			ereturn local estat_cmd = "regress_estat"
		}
		ereturn scalar N=`N'
		ereturn scalar J=`J'
		ereturn scalar J_pval=`p_j'
		ereturn matrix W=`Wght'
		ereturn local cmd spcgmm
	} // end of the first if 
	else { // replay
		if "`e(cmd)'" != "spcgmm" error 301
		syntax [, Level(`level')]
	}
	di
	if `ivm'==1 {
		di _skip(2) as res "Spatial 2-Step GMM (Mata version)"
		di 	_col(24) as res	" Number of observations = " _N	
		di 	_col(24) as res	" Crit. fnct. test of overid. restrictions = " %11.7f `J'
		di  _col(24) as res " DF= " `ovk'
		di  _col(24) as res " P-value = " %6.5f chi2tail(`ovk', `J') 
	}
	else {
		di _skip(2) as res "OLS Regression" 
		di _skip(2) as res "(Standard Errors Corrected for Heteroskedasticity and Spatial Dependence)"
		di _col(34) as res "Number of observations = " _N	
	}
	ereturn display, level(`level') 
	if `ivm'==1 ivreg_footnote, noline
end
version 10.1
local SSC string scalar
mata:
mata set matalnum on
mata set matastrict on
void spcgmm_funct(`SSC' depvar, `SSC' indv, `SSC' incvs, `SSC' excvs, `SSC' coor, `SSC' cutoff, `SSC' tousename)
 {
	string rowvector coefname, eqn
	string matrix mstripe
	real matrix x, incxx, excxx, z, what, coord
	real vector y, cut
	y = st_data(., depvar, tousename)
	n = rows(y)	
	x = st_data(., tokens(indv), tousename)
	tocons=st_local("noconst")
	incxx= st_data(., tokens(incvs), tousename)
	excxx= st_data(., tokens(excvs), tousename)
	if (tocons=="") {
		x=x, J(n,1,1)
		incxx=incxx, J(n,1,1)
	}
	z=incxx, excxx
// First stage
	B=quadcross(z, x)
	A=quadcross(z, y)
	invBB=cholinv(quadcross(B, B))
	BA=quadcross(B, A)
	bgminit=invBB*BA
	uhat=y-x*bgminit
	coord=st_data(.,tokens(coor), tousename)
	cut=st_matrix(cutoff)
	k=cols(z)
	dij=J(n,1,.)
	heeh=J(k, k, 0)
	if (st_local("degree")!="") {
		dij=J(n,1,.)
		for (i=1; i<=n; i++) {
			windowi=J(n,1,1)
			for (j=1; j<=cols(coord); j++) {
				dij=abs(coord[.,j]:-coord[i,j])
				windowi=(dij:<cut[j]):*(1:-dij:/cut[j]):*windowi		 
			}		
			heeh_hat = ((z[i,.]'*J(1,n,1)*uhat[i,1]):*(J(k,1,1)*uhat':*windowi'))*z
			heeh = heeh + heeh_hat 	
		}
	}	
	else { 
		distcut1 = cut[1,1]
		distcut2 = cut[1,2]
		cut_unit=69.172 // default unit is miles
		if (st_local("km")!="") cut_unit=111.325 
		lat_tr=cut_unit
		for (i=1; i<=n; i++) {
			lon_tr=cos(coord[i,1]*pi()/180)*cut_unit
			dij_h=lat_tr*abs(coord[.,1]:-coord[i,1])
			dij_v=lon_tr*abs(coord[.,2]:-coord[i,2])			
			windowi=(dij_h:<distcut1):*(1:-dij_h:/distcut1):*(dij_v:<distcut2):*(1:-dij_v:/distcut2)		
			heeh_hat = ((z[i,.]'*J(1,n,1)*uhat[i,1]):*(J(k,1,1)*uhat':*windowi'))*z
			heeh = heeh + heeh_hat 	
		}	
	}
	heeh=heeh/n
	if (!issymmetric(heeh)) _makesymmetric(heeh)	// May not be symmetric due rounding errors though in theory it should be
	what=invsym(heeh)
// second stage
	invbw=invsym(B'*what*B)
	bgmm=invbw*(B'*what*A) // same thing as writing invsym(x'*z*what*z'*x) * (x'*z*what*z'*y) since B=cross(z, x)
	covgmm= n * invbw // same thing as covgmm= 1/n * invsym(BN'*what*BN) after a little algebra with BN=B/n 
	e=y-x*bgmm
	gbar=1/n * quadcross(z, e)
	crit = n * quadcross(gbar, what) * gbar
	st_numscalar("J", crit)
	coefname = tokens(st_local("zvar"))

	if (tocons=="") coefname=coefname, "_cons"
	znames= tokens(st_local("hvar"))
	eqn=J(1, cols(x), "")
	eqnz=J(1, cols(z), "")
	mstripe=eqn', coefname'
	zstripe=eqnz', znames'
	
	st_matrix("r(w)", what)
	st_matrix("r(b)", bgmm')
	st_matrixcolstripe("r(b)", mstripe)
	st_matrix("r(V)", covgmm)
	st_matrixrowstripe("r(V)", mstripe)
	
	st_matrixcolstripe("r(V)", mstripe)
	st_matrixrowstripe("r(w)", zstripe)
	st_matrixcolstripe("r(w)", zstripe)
}
end
