*! Program to calculate the HAC standard errors in a spatial context (Kelejian and Prucha, 2007)
*! SPHAC feeds on crums left behind by ivregress and spivreg
*! Author P. Wilner Jeanty
*! Version 2.1: July 29, 2012---------> sphac now work after regress
*! Version 2.0: July 4, 2012 ---------> sphac now work after spivreg
*! Version 1.2: November 10, 2011 ----> Variable bandwidth now allowed 
*! Born date: July 6, 2009
program define sphac, eclass
	version 10.1
	if !inlist("`e(cmd)'", "regress", "ivregress", "spivreg") { // need to make it work after ivreg29
		di as err "{bf:sphac} does not work after `e(cmd)'" // ML estimation not allowed
		exit 198
	}
	if "`e(cmd)'"=="spivreg" & "`e(model)'"!="sar" {
		di as err "{bf:sphac} does not work after the `e(model)' model"
		exit 198
  	}
  	syntax, dmat(str) dfrom(str) [kernel(str) FBandw(numlist max=1 >0) VBandw(str) ///
			NOConst level(integer 95) model(str)] 
	qui count if e(sample)
	local N_obs=r(N)
	capture mata: mata drop sphac_*
	if "`fbandw'"!="" & "`vbandw'"!="" {
		di as err "Options {bf:fbandw()} and {bf:vbandw()} may not be combined"
		exit 198
	}
	if "`fbandw'`vbandw'"=="" {
		di as err "You must specify one of {bf:fbandw()} and {bf:vbandw()}" 
		exit 198
	}	
	if "`fbandw'"!="" local bw=`fbandw'
	if "`vbandw'"!="" {
		cap confirm numeric var `vbandw'
		local bw Variable
	}	
  	if !inlist("`dfrom'", "Mata", "Stata") {
		di as err "You must specified either Mata or Stata with {bf:dfrom()}"
		exit 198
  	}
  	else {
		if "`dfrom'"=="Mata" confirm file `dmat' 
		if "`dfrom'"=="Stata" confirm matrix `dmat' 
  	}
	if "`kernel'"!="" & !inlist("`kernel'", "Parzen", "Barlett", "Triangular", "Epanechnikov", "Bisquare") {
		di as err "The {bf:kernel()} option takes one of Parzen, Barlett, Triangular, Epanechnikov, and Bisquare"
		exit 198
	}
	if "`model'"!="" & !inlist("`model'", "ols", "iv", "sar", "iv-sar") { // sar is for spatial lag model estimated by S2SLS
		di as err "The {bf:model()} option takes one of ols, iv, sar, and iv-sar}"
		exit 198
  	}
	mata: sphac_kern="`kernel'"
	matrix beta=e(b)
	local y "`e(depvar)'"
	tempvar y_res 
	if "`model'"=="ols" | "`model'"=="iv" qui predict double `y_res', resid // model(iv) is assumed if not specified
	else if inlist("`model'", "iv-sar", "sar") & "`e(cmd)'"=="ivregress" qui predict double `y_res', resid  // residuals based on naive predictor
	else if "`model'"=="iv-sar" & "`e(cmd)'"=="spivreg" {
		tempvar y_hat 
		qui predict double `y_hat' // naive predictor is the default based upon which all residuals in the spatial econ lit have been calculated
		gen double `y_res'=`y'-`y_hat'
		spmat getmatrix `e(dlmat)' sphac_spW	// If users are planning to use sphac after spivreg they have to install spmat anyway
		mata: sphac_lag=1
	}
	if "`model'"=="ols" {
		local cdl `e(cmdline)'
		local cmd `e(cmd)' `e(depvar)'
		local exog : list  cdl - cmd  
	}
	else {
		local exog  "`e(exogr)'" 
		local inst "`e(insts)'"
		local exc_exog : list local(inst) - local(exog)
		local endog "`e(instd)'"
	}	
	if "`noconst'"=="" {
		tempvar cnst
		gen `cnst'=1
	}	
	local zvar `endog' `exog' `cnst'
	local hvar `exog' `cnst' `exc_exog'
    mata: CalcSPHAC2("`y_res'", "`zvar'", "`hvar'")
	if "`e(cmd)'"=="spivreg" local rowsn:colfullnames beta
	else local rowsn:colnames beta
	matrix rownames svcv = `rowsn'
	matrix colnames svcv = `rowsn'
	qui count if e(sample)
	local N=r(N)
	ereturn post beta svcv, depname(`y')
	ereturn local N `N'	
	ereturn local exogr "`exog'"
	if "`model'"!="ols" {
		ereturn local instd "`endog'"
		ereturn local insts "`exog' `exc_exog' "
	}	
	ereturn local kernel "`kernel'"
	ereturn local vcetype "SHAC"
  	ereturn local cmd "sphac"
	di
	di as res "Spatial HAC Standard Errors"
	di as res "Kernel = `kernel' " 
	di as res "Bandwidth =  `bw' "
	ereturn display, level(`level')
	if "`model'"!="ols" ivreg_footnote, noline 
	mata: mata drop sphac_*
end
version 10.1
mata:
	mata set matalnum on
 	void CalcSPHAC2(string scalar resvar, string scalar zxxs, string scalar hxxs) { 	
 	external sphac_lag, sphac_kern
	pointer(real) p
	st_view(T=., ., tokens(resvar))
  	st_view(Z=., ., tokens(zxxs))
  	st_view(H=., ., tokens(hxxs))
	if (sphac_lag==1) {
		p=findexternal("sphac_spW")
		st_view(y=., ., st_local("y")) 
		wy=*p*y
		Z=Z, wy
		wx=*p*H
		w2x=*p*wx
		H=H, wx, w2x
	}	
	HpH=cross(H, H)
	P=H*invsym(HpH)*H'
	zh=P*Z; zhpzh=cross(zh, zh) 
	N=rows(T)
	if (st_local("dfrom")=="Mata") {
		fh = fopen(st_local("dmat"), "r")
		dij=fgetmatrix(fh)
		fclose(fh)
	}
	else dij=st_matrix(st_local("dmat"))
	if (rows(dij)!=N) {
             ""
             errprintf("Number of observations (%f) not conformable with distance matrix size (%f by %f)\n", N, rows(dij), rows(dij))
             exit(3200)
    }
	Kij_h=J(N, N,0)
	if (st_local("vbandw")!="") {
		vb=st_data(., st_local("vbandw"))
		for (i=1; i<=N; ++i) {
			Kij_h[i,]=dij[i,]:/vb'[i]; 
		}	
	}	
	if (st_local("fbandw")!="") {
		sphac_fbw=strtoreal(st_local("fbandw"))
		Kij_h=dij:/sphac_fbw
	}	
	Lk=J(N,N,0)
	if (sphac_kern=="" | sphac_kern=="Barlett") {
		Lk=(Kij_h:<1):*(1:-Kij_h);  // the default is the Barlett window
	}	
	if (sphac_kern=="Epanechnikov") Lk=(1:-Kij_h:^2):*(Kij_h:<1)
	if (sphac_kern=="Triangular") Lk=(1:-Kij_h)
	if (sphac_kern=="Bisquare") Lk=(1:-(Kij_h:^2)):^2
	if (sphac_kern=="Parzen") {
		Lk=( Kij_h:<=0.5) :* (1:-6*Kij_h:^2 :+ 6*abs(Kij_h):^3) + (Kij_h:>0.5) :* (Kij_h:<=1) :* (2*(1:-abs(Kij_h)):^3)
	} 
	TT=T*T'
	TK=TT:*Lk 
	Psi=J(cols(H),cols(H),.)
	Psi=(1/N)*H'*TK*H 
	Phi1=(N^2)*invsym(zhpzh)*Z'*H*invsym(HpH)*Psi
	Phi2=invsym(HpH)*H'*Z*invsym(zhpzh)
	Phi=(1/N)*Phi1*Phi2 
	if (!issymmetric(Phi)) _makesymmetric(Phi) // Since a variable bandwidth results in a very strongly non-symmetric variance-covariance matrix
	st_matrix("svcv", Phi) 
}
end
